/// <reference path="../../includes.d.ts" />
/// <reference path="configPlugin.d.ts" />
/// <reference path="../../developer/ts/developerNavigation.d.ts" />
declare module Configs {
    class OperateType {
        static DELETE: string;
        static UPDATE: string;
        static PUT: string;
        static MOVE: string;
        static EXTRACT: string;
    }
    function createOracleInfo(array: Array<any>, id: number): {
        "id": number;
    };
    function shareInit($scope: any, $location: any, $routeParams: any): void;
    function createNewObejct(array: Array<any>, obj: any): any[];
    function oracleInfoOperate($http: any, url: string, operate: string, resource: any, fn?: (data, status) => void): void;
}
